==> maven-server-232.8660.185-sources.jar: org/jetbrains/idea/maven/server/ProjectResolutionRequest.java <==
// Copyright 2000-2023 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package org.jetbrains.idea.maven.server;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.idea.maven.model.MavenWorkspaceMap;

import java.io.File;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class ProjectResolutionRequest implements Serializable {
  private final @NotNull List<File> pomFiles;
  private final @NotNull List<String> activeProfiles = new ArrayList<>();
  private final @NotNull List<String> inactiveProfiles = new ArrayList<>();
  private final @Nullable MavenWorkspaceMap workspaceMap;
  private final boolean updateSnapshots;

  public ProjectResolutionRequest(@NotNull List<File> pomFiles,
                                  @NotNull Collection<String> activeProfiles,
                                  @NotNull Collection<String> inactiveProfiles,
                                  @Nullable MavenWorkspaceMap workspaceMap,
                                  boolean updateSnapshots) {
    this.pomFiles = pomFiles;
    this.activeProfiles.addAll(activeProfiles);
    this.inactiveProfiles.addAll(inactiveProfiles);
    this.workspaceMap = workspaceMap;
    this.updateSnapshots = updateSnapshots;
  }

  @NotNull
  public List<File> getPomFiles() {
    return pomFiles;
  }

  @NotNull
  public List<String> getActiveProfiles() {
    return activeProfiles;
  }

  @NotNull
  public List<String> getInactiveProfiles() {
    return inactiveProfiles;
  }

  @Nullable
  public MavenWorkspaceMap getWorkspaceMap() {
    return workspaceMap;
  }

  public boolean updateSnapshots() {
    return updateSnapshots;
  }
}

==> maven-server-232.9921.47-sources.jar: org/jetbrains/idea/maven/server/ProjectResolutionRequest.java <==
// Copyright 2000-2023 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package org.jetbrains.idea.maven.server;

import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.idea.maven.model.MavenWorkspaceMap;

import java.io.File;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

public class ProjectResolutionRequest implements Serializable {
  private final @NotNull List<File> pomFiles;
  private final @NotNull List<String> activeProfiles = new ArrayList<>();
  private final @NotNull List<String> inactiveProfiles = new ArrayList<>();
  private final @Nullable MavenWorkspaceMap workspaceMap;
  private final boolean updateSnapshots;

  public ProjectResolutionRequest(@NotNull List<File> pomFiles,
                                  @NotNull Collection<String> activeProfiles,
                                  @NotNull Collection<String> inactiveProfiles,
                                  @Nullable MavenWorkspaceMap workspaceMap,
                                  boolean updateSnapshots) {
    this.pomFiles = new ArrayList<>(pomFiles);
    this.activeProfiles.addAll(activeProfiles);
    this.inactiveProfiles.addAll(inactiveProfiles);
    this.workspaceMap = workspaceMap;
    this.updateSnapshots = updateSnapshots;
  }

  @NotNull
  public List<File> getPomFiles() {
    return pomFiles;
  }

  @NotNull
  public List<String> getActiveProfiles() {
    return activeProfiles;
  }

  @NotNull
  public List<String> getInactiveProfiles() {
    return inactiveProfiles;
  }

  @Nullable
  public MavenWorkspaceMap getWorkspaceMap() {
    return workspaceMap;
  }

  public boolean updateSnapshots() {
    return updateSnapshots;
  }
}
